==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/PARTNERDATAFLOWSTUDIOCATALOGUUID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PARTNERDATAFLOWSTUDIOCATALOGUUID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PARTNERDATAFLOWSTUDIOCATALOGUUID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATAFLOWSTUDIOCATALOGUUID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTNERDATAFLOWSTUDIOCATALOGUUID_Type", propOrder = {
    "dataflowstudiocataloguuid"
})
public class PARTNERDATAFLOWSTUDIOCATALOGUUID_Type {

    @XmlElement(name = "DATAFLOWSTUDIOCATALOGUUID", required = true)
    protected String dataflowstudiocataloguuid;

    /**
     * Gets the value of the dataflowstudiocataloguuid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATAFLOWSTUDIOCATALOGUUID() {
        return dataflowstudiocataloguuid;
    }

    /**
     * Sets the value of the dataflowstudiocataloguuid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATAFLOWSTUDIOCATALOGUUID(String value) {
        this.dataflowstudiocataloguuid = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/PARTNERDATAFLOWSTUDIOCATALOGUUID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PARTNERDATAFLOWSTUDIOCATALOGUUID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="PARTNERDATAFLOWSTUDIOCATALOGUUID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DATAFLOWSTUDIOCATALOGUUID"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTNERDATAFLOWSTUDIOCATALOGUUID_Type", propOrder = {
    "dataflowstudiocataloguuid"
})
public class PARTNERDATAFLOWSTUDIOCATALOGUUID_Type {

    @XmlElement(name = "DATAFLOWSTUDIOCATALOGUUID", required = true)
    protected String dataflowstudiocataloguuid;

    /**
     * Gets the value of the dataflowstudiocataloguuid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATAFLOWSTUDIOCATALOGUUID() {
        return dataflowstudiocataloguuid;
    }

    /**
     * Sets the value of the dataflowstudiocataloguuid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATAFLOWSTUDIOCATALOGUUID(String value) {
        this.dataflowstudiocataloguuid = value;
    }

}
